local AddonName, AddonTable = ...
local L = AddonTable.Localize
local AddonTitle = select(2, GetAddOnInfo(AddonName))
local PlainAddonTitle = AddonTitle:gsub("|c........", ""):gsub("|r", "")

function DRFrame_OnLoad()

	-- Create SavedVariables if they don't exist already
	if DRConfig == "" or DRConfig == nil then
		DRConfig = {
			["DeclineDuel"] = 'ON',
			["ShowChatMessage"] = 'ON',
			["ShowLoadMessage"] = 'ON',
			["DeclinePB"] = 'OFF',
			["OptionsWindow"] = 'HIDDEN'
		}
	end
	
	-- This variable tracks the total number of blocked duels across all of your characters
	if GlobalDC == "" or GlobalDC == nil then
		GlobalDC = 0
	end
	
	-- This variable tracks the total number of blocked duels on a single character
	if DuelsDeclined == "" or DuelsDeclined == nil then
		DuelsDeclined = 0
	end
	
	DRFrame:RegisterEvent("ADDON_LOADED")
	DRFrame:RegisterEvent("DUEL_REQUESTED")
	DRFrame:RegisterEvent("PET_BATTLE_PVP_DUEL_REQUESTED")
	
	-- already hidden by default, but just in case...
	DRFrame:Hide()
	
	if DRConfig.OptionsWindow == "" or DRConfig.OptionsWindow == nil then
		DRConfig.OptionsWindow = 'HIDDEN'
	end
	
end

function DRFrame_OnEvent(self, event, arg1)

if event == "ADDON_LOADED" and arg1 == "DuelResponse" then
	resetcheck()
	if DRConfig.ShowLoadMessage == "ON" then
		-- Show these messages in chat when the addon is loaded
		DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r v" .. GetAddOnMetadata("DuelResponse", "Version") .. L[" loaded successfully."])
	else
		return
	end
	
	if DRConfig.OptionsWindow == "" or DRConfig.OptionsWindow == nil then
		DRConfig.OptionsWindow = 'HIDDEN'
	end
elseif event == "PET_BATTLE_PVP_DUEL_REQUESTED" then
	-- Automatically declines a pet battle request if the option is enabled.
	if DRConfig.DeclinePB == 'ON' then
		if IsControlKeyDown() or IsAltKeyDown() then
			return
		else
			C_PetBattles.CancelPVPDuel()
			if DRConfig.ShowChatMessage == "ON" then
				DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Declined a pet battle request from "] .. arg1 .. ".")
			end
		end
	elseif DRConfig.DeclinePB == 'OFF' then
		return
	end
elseif event == "DUEL_REQUESTED" then

	if DRConfig.DeclineDuel == "OFF" then
		-- Check to see if the player has Resurrection Sickness; decline the request if they do.
		if UnitDebuff("player", L["Resurrection Sickness"]) then
			if DRConfig.ShowChatMessage == "ON" then
				DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Declined a duel request from "] .. arg1 .. L[" because you have "] .. GetSpellLink(15007) .. ".")
			end
			
			CancelDuel()
			increment_counters()
		else
			if IsControlKeyDown() or IsAltKeyDown() then
				return
			else
				if UnitIsAFK("player") == true then
					-- If the player is not blocking duels, but is marked as AFK, decline the request.
					CancelDuel()
					increment_counters()
			
					if DRConfig.ShowChatMessage == "ON" then
						DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. arg1 .. L[" challenged you while you were marked as Away."])
					end
				elseif UnitIsDND("player") == true then
					-- If the player is not blocking duels, but is marked as Busy, decline the request.
					CancelDuel()
					increment_counters()
			
					if DRConfig.ShowChatMessage == "ON" then
						DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. arg1 .. L[" challenged you while you were marked as Busy."])
					end
				end
			end
		end
	elseif DRConfig.DeclineDuel == "ON" then
		-- If the player is blocking duels, holding down either Control or Alt will allow a request to pass through
		if IsControlKeyDown() or IsAltKeyDown() then
			return
		else
		-- If the player is blocking duels, decline the request and increment the counters
			CancelDuel()
			increment_counters()
			
			if DRConfig.ShowChatMessage == "ON" then
				DEFAULT_CHAT_FRAME:AddMessage("|cFF00FFFF[" .. L["DuelResponse"] .."]|r " .. L["Declined a duel request from "] .. arg1 .. ".")
			end
		end
	else
		return
	end
end
end
	
function increment_counters()

-- Set up variables
local x = tonumber(GlobalDC)
local y = tonumber(DuelsDeclined)

-- Increment counters by 1
x = x + 1
y = y + 1

-- Save new variables
GlobalDC = x
DuelsDeclined = y

end

function resetcheck()

local x = tonumber(GlobalDC) -- number of duel requests blocked across all of your characters characters
local y = tonumber(DuelsDeclined) -- number of duel requests blocked on the character you are playing

-- Check to see if the all character counter has been reset to zero, and if the local counter is greater than zero.
-- If both of these conditions are true, then reset the local counter to zero.
if x == 0 and y > 0 then
	y = 0
	DuelsDeclined = y
end

end